import sqlite3
import os.path

import pygame
pygame.init()

import classes.MenuScene
import constants.core
import constants.scenes
import classes.SceneFactory

class ColourTower(object):
	def __init__(self):
		"""Initialises an instance of the class.
		
		"""
		# First set up database, otherwise the game can't be played.
		self.set_up_db()
		
		self.window = pygame.display.set_mode(
			constants.core.WINDOW_DIMENSIONS,
			0,
			0,
			0)
			
		self.next_scene = None
	
	
	def set_up_db(self):
		"""Sets up database and tables.
		
		"""
		db_conn = sqlite3.connect(
			os.path.join(
				os.getcwd(),
				constants.core.DB_DIR,
				constants.core.DB_NAME))
				
		db_cursor = db_conn.cursor()		
		db_cursor.execute(constants.core.DB_TABLE_TOWER_CREATE_STATEMENT)
		db_cursor.execute(constants.core.DB_TABLE_HIGHSCORE_CREATE_STATEMENT)
		db_conn.commit()
		db_conn.close()
		
	
	def run(self):
		"""Runs the game.
		
		"""
		self.run = True
		self.return_data = [constants.scenes.START_SCENE]		
		while self.run:
			if self.return_data[0] != "quit":
				self.determine_next_scene()
				self.prepare_scene()
				self.run_scene()
				
			else:
				self.run = False # Stop game.
					
		pygame.quit()
	
	
	def determine_next_scene(self):
		"""
		
		"""
		
		self.current_scene = self.return_data[0]
		if len(self.return_data) > 1:
			self.current_scene_dynamic_data = self.return_data[1:]
		else:
			self.current_scene_dynamic_data = None
	
	def prepare_scene(self):
		scene_data = constants.scenes.SCENES[self.current_scene]
		self.current_scene = classes.SceneFactory.SceneFactory.construct(
			self.window,
			scene_data["type"],
			scene_data["data"],
			self.current_scene_dynamic_data)
	
	
	def run_scene(self):
		self.return_data = self.current_scene.run()