import pygame
pygame.init()

import classes.MenuScene

import classes.Label
import classes.RectangleSetup
import classes.EntryFieldIncrementDecrement


class GenerateScene(classes.MenuScene.MenuScene):
	def __init__(self,
		_window,
		_data,
		_dynamic_data):
		"""
		
		Initialises an instance of this class.
		"""
		menu_scene_data = _data["menu_scene_data"]
		generate_scene_data = _data["generate_scene_data"]
		
		super(
			GenerateScene,
			self).__init__(
				_window,
				menu_scene_data,
				_dynamic_data)
			
		# Headings
		self.headings = pygame.sprite.Group()
		for heading in generate_scene_data["headings"]:
			self.headings.add(
				classes.Label.Label(heading));
		
		# Rectangles which the user can choose.
		self.rectangles_to_choose = pygame.sprite.Group()
		for data in generate_scene_data["tower_rectangles"]:
			self.rectangles_to_choose.add(
				classes.RectangleSetup.RectangleSetup(
					generate_scene_data["tower_rectangles"][data]))	

		# Create field for selecting how many block for the tower ought to be generated.
		self.increment_decrement_blocks = classes.EntryFieldIncrementDecrement.EntryFieldIncrementDecrement(
			generate_scene_data["entry_field_increment_decrement"])
			
		
		# A list that contains the chosen tower blocks
		self.chosen_tower_blocks = []
		
		# A value indicating the number of chosen tower blocks to generate.
		self.tower_blocks_to_generate = 0
		
	
	def process_events(self):
		super(
			GenerateScene,
			self).process_events()

		# Select rectangles:
		for block in self.rectangles_to_choose:
			if block.is_active:
				if pygame.mouse.get_pressed()[0] == True \
				and self.right_mouse_button_already_down == False:
					if block.chosen:
						block.set_unchosen()
						self.set_chosen_tower_blocks_remove(block.colour)
					else:
						block.set_chosen()
						self.set_chosen_tower_blocks_add(block.colour)
		
		# Check button increment:
		if self.increment_decrement_blocks.button_increment.is_active:
			if pygame.mouse.get_pressed()[0] == True \
			and self.right_mouse_button_already_down == False:
				# Increase number of blocks to generate.
				self.increment_decrement_blocks.n_blocks += 1
				self.tower_blocks_to_generate = self.increment_decrement_blocks.n_blocks
				
		# Check button decrement:
		if self.increment_decrement_blocks.button_decrement.is_active:
			if pygame.mouse.get_pressed()[0] == True \
			and self.right_mouse_button_already_down == False \
			and self.increment_decrement_blocks.n_blocks >= 1:
				# Decrease number of blocks to generate.
				self.increment_decrement_blocks.n_blocks -= 1
				self.tower_blocks_to_generate = self.increment_decrement_blocks.n_blocks

		if self.running == False:
			if self.return_data[0] == "scene_generate_tower":
				self.return_data = [
					self.return_data[0],
					self.chosen_tower_blocks,
					self.tower_blocks_to_generate]
				
			
	
	def update_objects(self):
		super(
			GenerateScene,
			self).update_objects()
		
		self.rectangles_to_choose.update()
		self.increment_decrement_blocks.update()
	
	
	def draw_objects(self):
		super(
			GenerateScene,
			self).draw_objects()
			
		self.headings.draw(self.window)
		self.rectangles_to_choose.draw(self.window)
		self.increment_decrement_blocks.draw(self.window)
	
	
	def set_chosen_tower_blocks_add(
		self,
		_colour):
		"""Sets chosen tower blocks list.
		
		"""
		self.chosen_tower_blocks.append(_colour)				
		
		
	def set_chosen_tower_blocks_remove(
		self,
		_colour):
		"""Sets chosen tower blocks list.
		
		"""
		if _colour in self.chosen_tower_blocks:
			self.chosen_tower_blocks.remove(_colour)	