import pygame
pygame.init()

import constants.core


class Scene(object):
	"""Represents a scene.
	
	"""
	def __init__(self,
		_window,
		_data,
		_dynamic_data):
		"""Initialises an instance of the class.
		
		"""
		self.window = _window
			
		self.window.fill(constants.core.WHITE)
			
		self.clock = pygame.time.Clock()	
		self.clock.tick(constants.core.FPS)	
		self.et = 1
		
		self.running = True
		self.events = pygame.event.get()
		
		# Data for the instance of the class.
		self.data = _data
		
		# Dynamic data generated within the game.
		self.dynamic_data = _dynamic_data
		
		# Return status codes. # Override this.  First value always is the command
		# on which scene to generate or whether to quit the game.
		self.return_data = None
		self.set_return_data(["quit",])
		
		# Prevent accidently clicking.
		self.right_mouse_button_down = False
		
		# Default background colour.
		self.background_colour = constants.core.WHITE
	
	
	def run(self):
		"""Runs the scene.
		
		"""
			
		self.running = True
		while self.running:
			# Fetch events from last update cycle.
			self.events = pygame.event.get()
			
			# Processes events.
			self.process_events()
			
			# Let clock tick and take note of elapsed time.
			self.et = self.clock.tick(constants.core.FPS)					
			
			# Update game objects.
			self.update_objects()
			
			# Draw default background.
			self.window.fill(self.background_colour)			
			
			# Draw game objects.
			self.draw_objects()
			
			# Refresh display to show the effets.
			pygame.display.flip()
		
		return self.return_data
	
	
	def process_events(self):
		"""Processes events.
		
		Override this method.
		"""		
		for e in self.events:
			if e.type == pygame.KEYDOWN:
				if e.key == pygame.K_ESCAPE:
					self.running = False
		
		self.check_block_mouse()
	
	
	def update_objects(self):
		"""Updates game objects.
		
		Override this method.
		"""
		pass
	
	
	def draw_objects(self):
		"""Draws game objects.
		
		Override this method.
		"""
		pass
	
	
	def check_block_mouse(self):
		if pygame.mouse.get_pressed()[0] == True \
		and self.right_mouse_button_down == False:
			self.right_mouse_button_down = True				
				
		elif pygame.mouse.get_pressed()[0] == True \
		and self.right_mouse_button_down == True:
			self.right_mouse_button_already_down = True					
		elif pygame.mouse.get_pressed()[0] == False:
			self.right_mouse_button_down = False
			self.right_mouse_button_already_down = False
	
	
	def set_return_data(
		self,
		_data):
		self.return_data = _data
