import string

import pygame
pygame.init()

import classes.Scene
import classes.NextBlock
import classes.TowerBlockSequence
import classes.ChooseBlock
import classes.Tower
import classes.Timer

class ScenePlay(classes.Scene.Scene):
	def __init__(
		self,
		_window,
		_data,
		_dynamic_data):
		"""
		
		"""
		super(
			ScenePlay,
			self).__init__(
				_window,
				_data,
				_dynamic_data)
				
		self.dynamic_data = _dynamic_data[0]
		
		print(_data["timer_data"])
		self.timer = classes.Timer.Timer(_data["timer_data"])
		
		self.tower = classes.Tower.Tower(_data["tower_data"])			
		
		self.choose_blocks = pygame.sprite.Group()
		self.choose_block_data = _data["choose_block_data"]
		self.create_choose_blocks()
		
		self.next_block = classes.NextBlock.NextBlock(_data["next_block_data"])
		
		# Convert comma separated values to list.
		# This will be our colour block sequence.
		self.sequence = self.dynamic_data[8].split(",")
		self.tower_block_sequence = classes.TowerBlockSequence.TowerBlockSequence(self.sequence)
		
		# Now set first colour block.
		self.next_block.set_next_block(
			self.tower_block_sequence.current_block_colour,
			self.tower_block_sequence.current_block_colour_label)
			
		
		# Reset elapsed time
		self.et = 0
			

	def create_choose_blocks(self):
		"""
		
		"""
		red_used = self.dynamic_data[2]
		blue_used = self.dynamic_data[3]
		yellow_used = self.dynamic_data[4]
		green_used = self.dynamic_data[5]
		grey_used = self.dynamic_data[6]
		purple_used = self.dynamic_data[7]
		
		_data = self.choose_block_data
		
		for x in _data:
			# Only create block if that colour is use in the tower.
			if _data[x]["colour"] == "red" and red_used:
				self.choose_blocks.add(classes.ChooseBlock.ChooseBlock(_data[x]))
				
			elif _data[x]["colour"] == "blue" and blue_used:
				self.choose_blocks.add(classes.ChooseBlock.ChooseBlock(_data[x]))
				
			elif _data[x]["colour"] == "yellow" and yellow_used:
				self.choose_blocks.add(classes.ChooseBlock.ChooseBlock(_data[x]))
				
			elif _data[x]["colour"] == "green" and green_used:
				self.choose_blocks.add(classes.ChooseBlock.ChooseBlock(_data[x]))
				
			elif _data[x]["colour"] == "grey" and grey_used:
				self.choose_blocks.add(classes.ChooseBlock.ChooseBlock(_data[x]))

			elif _data[x]["colour"] == "purple" and purple_used:
				self.choose_blocks.add(classes.ChooseBlock.ChooseBlock(_data[x]))
		
	
	def process_events(self):
		"""
		
		"""
		super(ScenePlay, self).process_events()
		
		for block in self.choose_blocks:
			if block.is_active:
				if pygame.mouse.get_pressed()[0] == True \
				and self.right_mouse_button_already_down == False:		
					# Check if clicked colour and given colour match.
					if self.colours_match(block):
						# Add to tower blocks.
						self.tower.update_blocks(self.next_block.colour)
						# Pick next colour.  If there are none, quit.
						if not self.tower_block_sequence.end_reached:
							self.tower_block_sequence.choose_next_block()
							self.set_next_colour_from_sequence()
						else:
							self.running = False
							self.return_data[0] = "scene_score"
						
		if self.running == False:
			if self.return_data[0] == "quit":
				self.return_data = ["scene_main_menu"]
			else:
				self.return_data = [
					"scene_score",
					self.dynamic_data[0],
					self.timer.time_in_milliseconds]
		
		
	def update_objects(self):
		"""
		
		"""
		super(ScenePlay, self).update_objects()
		
		self.choose_blocks.update()
		self.timer.update(self.et)
	
	
	def draw_objects(self):
		"""
		
		"""
		super(ScenePlay, self).draw_objects()
					
		self.next_block.draw(self.window)
		self.choose_blocks.draw(self.window)
		self.tower.draw(self.window)
		for x in self.tower.blocks:
			self.window.blit(x.image, x.rect)
		self.window.blit(
			self.timer.image,
			self.timer.rect)
	
	def colours_match(
		self,
		_block):
		"""
		
		"""
		if _block.colour == self.next_block.colour_label:
			return True
		else:
			return False
	
	
	def set_next_colour_from_sequence(self):
		self.next_block.set_next_block(
			self.tower_block_sequence.current_block_colour,
			self.tower_block_sequence.current_block_colour_label)	
