import os.path
import sqlite3

import pygame
pygame.init()

import constants.core
import classes.Label
import classes.MenuItem
import classes.Rectangle


class TowerChooserBase(pygame.sprite.Group):
	"""Base class for the tower chooser.
	
	Used before highscores and starting a game.
	"""
	def __init__(
		self,
		_data):
		"""Initalises an instance of this class.
		
		"""
		super(TowerChooserBase, self).__init__()
		
		self.data = _data
		
		# Load all tower data.
		self.all_tower_data = []
		self.load_all_tower_data()
		
		self.max_towers = len(self.all_tower_data)
		self.cur_id = 0
		self.cur_tower_data = self.all_tower_data[self.cur_id]
		
		# Create submenu to choose tower.
		# Headings
		self.heading = classes.Label.Label(self.data["heading"]);
		self.add(self.heading)
		
		# Text: "Blocks: #"
		self.text_n_blocks = classes.Label.Label(self.data["text_n_blocks"])
		self.add(self.text_n_blocks)
		
		# Show record if there is one.
		self.record = classes.Label.Label(self.data["record"])
		self.add(self.record)
				
		# Blocks which the user can use i the game.
		self.blocks = pygame.sprite.Group()
		self.add(self.blocks)
		
		# Buttons to choose previous or next tower.
		self.next_tower_button = classes.MenuItem.MenuItem(self.data["menu_items"]["next"])
		self.add(self.next_tower_button)
		
		self.previous_tower_button = classes.MenuItem.MenuItem(self.data["menu_items"]["previous"])
		self.add(self.previous_tower_button)
		
		# Initially shown is the first tower data and its' colour blocks thar are used.
		self.update_tower()

	
	def load_all_tower_data(self):
		"""Loads all tower data from the DB.
		
		"""
		db_conn = sqlite3.connect(
			os.path.join(
				os.getcwd(),
				constants.core.DB_DIR,
				constants.core.DB_NAME))
				
		db_cursor = db_conn.cursor()
		
		db_cursor.execute("SELECT * FROM %s" % constants.core.DB_TABLE_TOWER)
		self.all_tower_data = db_cursor.fetchall()
		

	def set_cur_tower_data(self):
		self.cur_tower_data = self.all_tower_data[self.cur_id]
	
	
	def show_tower_data(self):
		"""Shows tower data.
		
		"""
		self.heading.change_value("#%s" % str(self.cur_tower_data[0]))
		self.text_n_blocks.change_value("Blocks: %s" % str(self.cur_tower_data[1]))
		self.show_record_data()
		
		self.remove(self.blocks)
		self.blocks.empty()
		

		for data in self.data["blocks"]:
			if self.colour_exists_in_tower(self.data["blocks"][data]["colour"]):
				self.blocks.add(
					classes.Rectangle.Rectangle(
						self.data["blocks"][data]["base_data"]))

		self.add(self.blocks)
		
	def update_tower(self):
		"""
		
		"""
		self.set_cur_tower_data()
		self.show_tower_data()
		
	
	def colour_exists_in_tower(
		self,
		_colour):
		"""
		
		"""
		if _colour == "red" and self.cur_tower_data[2] == 1:
			return True
		elif _colour == "blue" and self.cur_tower_data[3] == 1:
			return True
		elif _colour == "yellow" and self.cur_tower_data[4] == 1:
			return True
		elif _colour == "green" and self.cur_tower_data[5] == 1:
			return True
		elif _colour == "grey" and self.cur_tower_data[6] == 1:
			return True
		elif _colour == "purple" and self.cur_tower_data[7] == 1:
			return True
		else:
			return False
	
	
	def show_record_data(self):
		"""
		
		"""
		db_conn = sqlite3.connect(
			os.path.join(
				os.getcwd(),
				constants.core.DB_DIR,
				constants.core.DB_NAME))
				
		db_cursor = db_conn.cursor()
		
		db_cursor.execute("SELECT * FROM %s WHERE tower_id = %d" % (constants.core.DB_TABLE_HIGHSCORE, self.cur_tower_data[0]))
		result = db_cursor.fetchone()	
		db_conn.close()
		
		if result == None:
			self.record.change_value("-")
		else:
			# Format first.
			millis = result[1]
			milliseconds = (millis % 1000) / 10
			seconds = (millis / 1000) % 60
			seconds = int(seconds)
			minutes = (millis / (1000 * 60)) % 60
			minutes = int(minutes)
			hours = (millis / (1000 * 60 * 60)) % 24
			
			hms = "Record: %.2d:%.2d:%.2d:%.2d" % (hours, minutes, seconds, milliseconds)			
			self.record.change_value(hms)